/*
 * Photo Image Print System
 * Copyright (C) 2000-2004 EPSON KOWA Corporation.
 * Copyright (C) SEIKO EPSON CORPORATION 2000-2004.
 *
 *  This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * As a special exception, EPSON KOWA Corporation gives permission to
 * link the code of this program with libraries which are covered by
 * the EPSON KOWA PUBLIC LICENCE and distribute their linked
 * combinations.  You must obey the GNU General Public License in all
 * respects for all of the code used other than the libraries which
 * are covered by EPSON KOWA PUBLIC LICENCE.
 */
#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#ifndef __OPT_H__
#define __OPT_H__

#ifdef PM800C
#include "optPM800C.rsc"
#endif

#ifdef PM770C
#include "optPM770C.rsc"
#endif

#ifdef PM760C
#include "optPM760C.rsc"
#endif

#ifdef PM820_3300C
#include "optPM820_3300C.rsc"
#endif

#ifdef PM750_2000C
#include "optPM750_2000C.rsc"
#endif

#ifdef PM3000C
#include "optPM3000C.rsc"
#endif

#ifdef PM2200C
#include "optPM2200C.rsc"
#endif

#ifdef PM3300C
#include "optPM3300C.rsc"
#endif

#ifdef PM900C
#include "optPM900C.rsc"
#endif

#ifdef PM670C
#include "optPM670C.rsc"
#endif

#ifdef PM880C
#include "optPM880C.rsc"
#endif

#ifdef PM780C
#include "optPM780C.rsc"
#endif

#ifdef PM3500C
#include "optPM3500C.rsc"
#endif

#ifdef CL700
#include "optCL700.rsc"
#endif

#ifdef SC580
#include "optSC580.rsc"
#endif

#ifdef SC480
#include "optSC480.rsc"
#endif

#ifdef PM790PT
#include "optPM790PT.rsc"
#endif

#ifdef SC40S
#include "optSC40S.rsc"
#endif

#ifdef SC680_777
#include "optSC680_777.rsc"
#endif

#ifdef SC880
#include "optSC880.rsc"
#endif

#ifdef SC980
#include "optSC980.rsc"
#endif

#ifdef SC20S
#include "optSC20S.rsc"
#endif

#ifdef PM720C
#include "optPM720C.rsc"
#endif

#ifdef PM780CS
#include "optPM780CS.rsc"
#endif

#ifdef PM920C
#include "optPM920C.rsc"
#endif

#ifdef PM820CUG
#include "optPM820CUG.rsc"
#endif

#ifdef PM3300CUG
#include "optPM3300CUG.rsc"
#endif

#ifdef SP810_820
#include "optSP810_820.rsc"
#endif

#include "optBase.rsc"

#endif /* __OPT_H__ */
